@@ -5,7 +5,5 @@ this empty if your package's modules and subpackages do not share
 any code.
 (If your package is just a module, then you can put that code here.)
 """
-
-def foo(x, y):
-  if x == y: return True
-	else: print("hello")
\ No newline at end of file
+def test():
+  print ("hello")
\ No newline at end of file
